import subprocess
import platform


def run(dev):
    try:
        system = platform.system()
        if dev:
            print(system)
        if system == 'Windows':
            command = f"pip freeze > requirements.txt"
            subprocess.run(command, shell=True)

        elif system == 'Linux':
            print(system)
        elif system == 'Darwin':
            print(system)
        else:
            print("OS를 알 수 없음")
    except Exception as e:
        print(e)



import glfw
from Rafflesia.Graphics import td_windows


class GraphicsManager:
    def __init__(self, dev=False):
        self.dev = dev
        glfw.init()
        super(GraphicsManager, self).__init__()

    def create_window(self, x=1280, y=720, window_title="Rafflesia_window", fullscreen=False):
        window = td_windows.create_window(x, y, window_title, fullscreen, self.dev)
        return window

    def make_context_current(self, window):
        td_windows.make_context_current(window, self.dev)

    def window_should_close(self, window):
        w = td_windows.window_should_close(window, self.dev)
        return w

    def swap_buffers(self, window):
        td_windows.swap_buffers(window, self.dev)

    def poll_events(self):
        td_windows.poll_events(self.dev)

    def terminate(self):
        td_windows.terminate(self.dev)



import subprocess
import platform
import time


def package(main, company_name, product_version, deploy_dir_name, ico, withconsole, dev):
    try:
        system = platform.system()
        if dev:
            print(system)
        if system == 'Windows':
            if withconsole:
                command = f"python -m nuitka --mingw64 --show-modules --follow-imports --windows-icon-from-ico={ico} " \
                          f"--windows-company-name={company_name} --windows-product-version={product_version} " \
                          f"--output-dir={deploy_dir_name} " \
                          f"--include-module=OpenGL.platform " \
                          f"--include-module=OpenGL.arrays " \
                          f"{main}"
            else:
                command = f"python -m nuitka --mingw64 --show-modules --follow-imports --windows-disable-console " \
                          f"--windows-company-name={company_name} --windows-product-version={product_version} " \
                          f"--windows-icon-from-ico={ico} --output-dir={deploy_dir_name} " \
                          f"--include-module=OpenGL.platform " \
                          f"--include-module=OpenGL.arrays " \
                          f"{main}"
            if dev:
                print(command)

            start = time.time()
            subprocess.run(command.split(' '), shell=True)
            end = time.time()
            if dev:
                print(f"{end-start}s 사용됨")

        elif system == 'Linux':
            print(system)
        elif system == 'Darwin':
            print(system)
        else:
            print("OS를 알 수 없음")
    except Exception as e:
        print(e)



import glfw


def create_window(x, y, window_title, fullscreen, dev):
    try:
        if fullscreen:
            monitor = glfw.get_primary_monitor()
            vidmode = glfw.get_video_mode(monitor)
            window = glfw.create_window(vidmode.size.width, vidmode.size.height, window_title, monitor, None)
        else:
            window = glfw.create_window(x, y, window_title, None, None)
        if dev:
            print(f"Rafflesia Graphics / windows: {window_title} window 생성")

        return window

    except Exception as e:
        print(e)


def make_context_current(window, dev):
    try:
        if dev:
            print("Rafflesia Graphics / windows: make_content_current")
        glfw.make_context_current(window)
    except Exception as e:
        print(e)


def window_should_close(window, dev):
    try:
        return glfw.window_should_close(window)
    except Exception as e:
        print(e)


def swap_buffers(window, dev):
    try:
        glfw.swap_buffers(window)
    except Exception as e:
        print(e)


def poll_events(dev):
    try:
        glfw.poll_events()
    except Exception as e:
        print(e)


def terminate(dev):
    try:
        if dev:
            print("Rafflesia Graphics / windows: 윈도우 종료")

        glfw.terminate()
    except Exception as e:
        print(e)



import pygame


def long_get_pos(dev):
    try:
        if dev:
            print(f"Rafflesia Audio / long_get_pos: long pos {pygame.mixer.music.get_pos()}ms")
        return pygame.mixer.music.get_pos()
    except Exception as e:
        print(e)


def long_set_pos(value, dev):
    try:
        pygame.mixer.music.set_pos(value)
        if dev:
            print(f"Rafflesia Audio / long_set_pos: long pos를 {value}으로 세팅")
    except Exception as e:
        print(e)



import pygame


def long_get_volume(dev):
    try:
        if dev:
            print(f"Rafflesia Audio / long_get_volume: long volume {pygame.mixer.music.get_volume()*100}%")
        return pygame.mixer.music.get_volume()
    except Exception as e:
        print(e)


def long_set_volume(value, dev):
    try:
        pygame.mixer.music.set_volume(value)
        if dev:
            print(f"Rafflesia Audio / long_set_volume: long volume을 {value}으로 세팅")
    except Exception as e:
        print(e)
